pyak47
======

Performance Test Framework.

.. image:: https://secure.travis-ci.org/kakwa/pyak47.png?branch=master
    :target: http://travis-ci.org/kakwa/pyak47
    :alt: Travis CI

.. image:: https://pypip.in/d/pyak47/badge.png
    :target: https://pypi.python.org/pypi/pyak47
    :alt: Number of PyPI downloads

|

.. figure:: https://raw2.github.com/kakwa/pyak47/master/docs/assets/graphs.png
    :align: center

----

:Dev: `Pyak47 source <https://github.com/kakwa/pyak47>`_
:PyPI: `Pyak47 package <http://pypi.python.org/pypi/pyak47>`_
:Doc: `Documentation <http://pyak47.readthedocs.org>`_
:License: `GNU LGPLv3 <http://www.gnu.org/licenses/lgpl.html>`_
:Author: Pierre-Francois Carpentier - copyright 2014

----

:Original author: `Corey Goldberg <http://goldb.org>`_ - copyright 2010-2013
:Original project: `multimechanize.com <http://multimechanize.com>`_

----


Notice
======

This work is a fork of `Multi-Mechanize <http://multimechanize.com>`_ from Corey Goldberg.

Original work copyright:

* Copyright: (c) 2010-2013 Corey Goldberg (cgoldberg _at_ gmail.com)

License
-------

pyak47 is released under GNU LGPLv3.

Installation
------------

Dependancies
~~~~~~~~~~~~

* python 2.6 or python 2.7
* matplotlib

Installation
~~~~~~~~~~~~

Pyak47 can be installed from `PyPI <http://pypi.python.org/pypi/pyak47>`_ using `pip <http://www.pip-installer.org>`_::
    
    pip install -U pyak47

... or download the `source distribution from PyPI <http://pypi.python.org/pypi/pyak47#downloads>`_, unarchive, and run::

    python setup.py install

Documentation
-------------

please visit: http://pyak47.rtfd.org

Project initialization
----------------------

To create a project, run::

    pyak47-newproject myproject

To run your project::

   pyak47-run myproject
